#!/usr/bin/env python3


import sys


gen = {
    'end': 0,
    'error': 1,
    'bold': 1,
    'italic': 3,
    'underline': 4,
    'strike': 9,
    'dblack': 30,
    'dred': 31,
    'dgreen': 32,
    'dyellow': 33,
    'dblue': 34,
    'dpurple': 35,
    'dteal': 36,
    'dwhite': 37,
    '_dblack': 40,
    '_dred': 41,
    '_dgreen': 42,
    '_dyellow': 43,
    '_dblue': 44,
    '_dpurple': 45,
    '_dteal': 46,
    '_black': 99,
    '_grey': 100,
    '_red': 101,
    '_green': 102,
    '_yellow': 103,
    '_blue': 104,
    '_purple': 105,
    '_cyan': 106,
    '_white': 107,
    '_dwhite': 47,
    'black': 90,
    'red': 91,
    'green': 92,
    'yellow': 93,
    'blue': 94,
    'purple': 95,
    'teal': 96,
    'white': 97
}

colors = {x: '\033[{}m'.format(gen[x]) for x in gen}


def cprint(text, prefix='', suffix='[end]\n', file=sys.stdout):
    output = ''
    text = prefix + text + suffix
    c = []
    color = [x[:x.find(']')] if '/' in x else x[:x.find(']')] for x in
             text.split('[') if x[:x.find(']')].replace('/', '') in colors]
    for col in color:
        if col.startswith('/'):
            c.reverse()
            del c[c.index(col[1:])]
            c.reverse()
        else:
            c.append(col)
        text = (text.replace('[' + col + ']', colors['end'] +
                ''.join(colors[x.replace('/', '')] for x in c))
                if col.startswith('/') else text.replace('[' + col + ']',
                colors[col]))
    print( text, end='', file=file)
    return None



#!/usr/bin/env python3


import threading


class asthread(object):
	def __init__(self, daemon=False):
		self.daemon = daemon

	def __call__(self, function):
		def inner(*args, **kwargs):
			thread = threading.Thread(target=function, args=args,
									  kwargs=kwargs)
			thread.daemon = self.daemon
			thread.start()
			return None
		return inner



#!/usr/bin/env python3


from setuptools import setup


setup(name='youtube_watcher',
        version='0.9.4',
        description='A simple program to list new YouTube videos and download them',
        author='Steven J. Core',
        url='https://github.com/Sjc1000/youtube_watcher',
        author_email='42Echo6Alpha@gmail.com',
        license='GPL3.0',
        packages=['youtube_watcher'],
        zip_safe=False,
        include_package_data=True,
        install_requires=[
            'bs4',
            'youtube-dl'
            ],
        entry_points={
            'console_scripts': [
                'youtube_watcher = youtube_watcher.__init__:main'
                ]
            })
